//----------------------------------------------------------------------------------------------------
// Debug module header file
//
// Geoff Audy, October 11th 2000
// Geoff Audy, October 25th 2000 (Changed the function named 'DEBUG_PrintDebugWindow' to 'DEBUG_Print'
// Geoff Audy, October 28th 2000 (Added functions 'DEBUG_SetMode')

// Copyright (C)2002 Sony Computer Entertainment America Inc.
//
// This file is subject to the terms and conditions of the GNU
// General Public Licence Version 2.  See the file "COPYING"
// in the main directory of this archive for more details.
//----------------------------------------------------------------------------------------------------

#ifndef __DEBUG_H__
#define __DEBUG_H__

#include <stdio.h>
#include <stdarg.h>

#ifdef __cplusplus
extern "C" {
#endif

//-------------------------------------
#define  DEBUG_MODE_ON     0x00000001  // For turning debug information on or off
#define  DEBUG_MODE_OFF    0x00000002

#define  DEBUG_MODE_FILE   0x00000004  // Permits to redirect debug information to a file
#define  DEBUG_MODE_PRINT  0x00000008  // or regular output when calling 'DEBUG_Print'

#ifdef _DEBUG_

#define  DEBUG_ASSERT(f)                                                         \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : Assertion '%s' failed\n", __FILE__, __LINE__, #f);  \
   }

#define  DEBUG_ASSERT_MSG(f,msg)                                                 \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : %s\n", __FILE__, __LINE__, msg);                    \
   }

#define  DEBUG_ASSERT_RET(f,retval)                                              \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : Assertion '%s' failed\n", __FILE__, __LINE__, #f);  \
      return (retval);                                                           \
   }

#define  DEBUG_ASSERT_HALT(f)                                                    \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : Assertion '%s' failed\n", __FILE__, __LINE__, #f);  \
      while (1) {}                                                               \
   }

#define  DEBUG_ASSERT_RETNOTHING(f)                                              \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : Assertion '%s' failed\n", __FILE__, __LINE__, #f);  \
      return;                                                                    \
   }

#define  DEBUG_ASSERT_MSG_RET(f,msg,retval)                                      \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : %s\n", __FILE__, __LINE__, msg);                    \
      return (retval);                                                           \
   }

#define  DEBUG_ASSERT_MSG_RETNOTHING(f,msg)                                      \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : %s\n", __FILE__, __LINE__, msg);                    \
      return;                                                                    \
   }

#define  DEBUG_ASSERT_MSG_HALT(f,msg)                                            \
   if (!(f))                                                                     \
   {                                                                             \
      DEBUG_Print ("%s(%d) : %s\n", __FILE__, __LINE__, msg);                    \
      while (1) {}                                                               \
   }

#else

#define  DEBUG_ASSERT(f)                        f;
#define  DEBUG_ASSERT_MSG(f,msg)                f;
#define  DEBUG_ASSERT_RET(f,retval)             f;
#define  DEBUG_ASSERT_HALT(f)                   f;
#define  DEBUG_ASSERT_RETNOTHING(f)             f;
#define  DEBUG_ASSERT_MSG_RET(f,msg,retval)     f;
#define  DEBUG_ASSERT_MSG_RETNOTHING(f,msg)     f;
#define  DEBUG_ASSERT_MSG_HALT(f,msg)           f;

#endif

enum
{
   DEBUG_RET_OK = 0,
   DEBUG_RET_INVALIDPARAMETER,
   DEBUG_RET_ERROR,

   DEBUG_RET_MAX
};

//-------------------------------------
void         DEBUG_Print (char *formatstr, ...);
unsigned int DEBUG_SetMode (unsigned int mode);

#ifdef __cplusplus
}
#endif

#endif   // __DEBUG_H__
