//---------------------------------------------------------------------
// Copyright (C)2002 Matt J. Scott.
//
// This file is subject to the terms and conditions of the GNU General
// Public License Version 2.  See the file "COPYING" in the main
// directory of this archive for more details
//---------------------------------------------------------------------

#include <stdio.h>
#include <stdlib.h>
#include "pack.h"

struct stick {
	int		p1;
	int 	p2;
	float	len;
	int		fill;
};

struct limb {
	int		p1;
	int 	p2;
	int		p3;
	int		p4;
	float	scalex;
	float	scaley;
	float	scalez;
	int		usex;
};

main () {

	FILE *fd;

	if ( (fd = fopen ("marionette.dat", "wb+")) < 0) {
		printf ("Can't open marionette.dat\n");
		exit (-1);
	}
	
	// write out control quad word
	int noinput = 1;
	int prevpad = 0xFFF7;
	int matrixmode = 0;
	int matrixmodecnt = 1;
	fwrite (&noinput, sizeof(int), 1, fd);
	fwrite (&prevpad, sizeof(int), 1, fd);
	fwrite (&matrixmode, sizeof(int), 1, fd);
	fwrite (&matrixmodecnt, sizeof(int), 1, fd);

	// write out the four preformatted giftags
	int giftag[4];

	// color gif tag 
	giftag[0] = 0x00000001;
	giftag[1] = 0x10000000;
	giftag[2] = 0x00000001;
	giftag[3] = 0x00000000;
	fwrite (giftag, sizeof(int), 4, fd);

	// sprite gif tag
	giftag[0] = 0x00000035;		// EOP = 0, NLOOP = 53
	giftag[1] = 0x20034000;		// NREG = 2, pre = 1, prim - sprite
	giftag[2] = 0x00000044;		// XYZF2 x2
	giftag[3] = 0x00000000;	
	fwrite (giftag, sizeof(int), 4, fd);

	// line gif tag
	giftag[0] = 0x0000803C;		// EOP = 1, NLOOP = 60
	giftag[1] = 0x2000C000;		// NREG = 2, pre = 1, prim - line
	giftag[2] = 0x00000044;		// XYZF2 x2
	giftag[3] = 0x00000000;	
	fwrite (giftag, sizeof(int), 4, fd);
	
	// mesh giftag
	giftag[0] = 0x00000000;
	giftag[1] = 0x20064000;		// NREG = 2, pre = 1, prim = strip
	giftag[2] = 0x00000041;
	giftag[3] = 0x00000000;
	fwrite (giftag, sizeof(int), 4, fd);
	
	// linestrip giftag
	giftag[0] = 0x00008005;
	giftag[1] = 0x10014000;		// NREG = 1, pre = 1, prim = line strip
	giftag[2] = 0x00000004;
	giftag[3] = 0x00000000;
	fwrite (giftag, sizeof(int), 4, fd);
	
	// NULL giftab
	giftag[0] = 0x00008000;		// EOP = 1
	giftag[1] = 0x00000000;
	giftag[2] = 0x00000000;
	giftag[3] = 0x00000000;
	fwrite (giftag, sizeof(int), 4, fd);

	float frgbaq[4];
	frgbaq[0] = 240.00f; 	// red
	frgbaq[1] = 190.00f;	// green
	frgbaq[2] = 190.00f;	// blue
	frgbaq[3] =   0.0f;		// alpha
	fwrite (frgbaq, sizeof(float), 4, fd);

	frgbaq[0] = 128.00f; 	// red
	frgbaq[1] = 128.00f;	// green
	frgbaq[2] = 128.00f;	// blue
	frgbaq[3] =   0.0f;		// alpha
	fwrite (frgbaq, sizeof(float), 4, fd);

	int rgbaq[4];
	rgbaq[0] = 80;		// red
	rgbaq[1] = 80;		// green
	rgbaq[2] = 80;		// blue
	rgbaq[3] = 0;		// alpha
	fwrite (rgbaq, sizeof(int), 4, fd);

	rgbaq[0] = 100;		// red
	rgbaq[1] = 100;		// green
	rgbaq[2] = 100;		// blue
	rgbaq[3] = 0;		// alpha
	fwrite (rgbaq, sizeof(int), 4, fd);

	// gravity
	float gravity[4] = { 0.0f, 0.01f, 0.0f, 0.0f };
	fwrite (gravity, sizeof(float), 4, fd);
	
	// minimum and maximum vector
	float minvbig[4] = { -44.98f, -60.00f,  -75.00f, 0.0f };
	float maxvbig[4] = {  44.98f,  32.00f,  100.00f, 0.0f };
	fwrite (minvbig, sizeof(float), 4, fd);
	fwrite (maxvbig, sizeof(float), 4, fd);
	float minvsmall[4] = { -45.0f, -40.0f,  -35.0f, 0.0f };
	float maxvsmall[4] = {  45.0f,  10.0f,   70.0f, 0.0f };
	fwrite (minvsmall, sizeof(float), 4, fd);
	fwrite (maxvsmall, sizeof(float), 4, fd);
	
	// 	scrz:		distance to screen
	// 	ax, ay:		aspect ratio
	// 	cx, cy:		center
	// 	zmin, zmax:	Z-buffer range
	// 	nearz, farz:	near, far edge
	float scrz  = 512.0f;
	float zmin  = 1.0f;
	float zmax  = 16777215.0f;
	float nearz = 1.0f;
	float farz  = 65536.0f;
	float ax    = 1.00f;	// aspect ration
	float ay    = 0.47f;
	float cx    = 2048.0f;	// center of screen
	float cy    = 2048.0f;
	float az    = farz * nearz * (-zmin + zmax) / (-nearz + farz);
	float cz    = (-zmax * nearz + zmin * farz) / (-nearz + farz);;

	float m1[4][4] = { 
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f
		};

	m1[0][0] = scrz;
	m1[1][1] = scrz;
	m1[2][3] = 1.0f;
	m1[3][2] = 1.0f;

	float m2[4][4] = { 
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f
		};

	m2[0][0] = ax;
	m2[1][1] = ay;
	m2[2][2] = az;
	m2[3][3] = 1.0f;

	m2[3][0] = cx;	
	m2[3][1] = cy;	
	m2[3][2] = cz;

	float cam_scr[4][4] = { 
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 0.0f
		};

	int i, j;
	for(i=0; i<4; i++){
		for(j=0; j<4; j++){
       		cam_scr[i][j] = m1[i][0] * m2[0][j] + m1[i][1] * m2[1][j] +
	 			            m1[i][2] * m2[2][j] + m1[i][3] * m2[3][j];
		}
	}

	/*
	printf ("%16.4f %16.4f %16.4f %16.4f\n", 
			cam_scr[0][0], cam_scr[0][1], cam_scr[0][2], cam_scr[0][3]);
	printf ("%16.4f %16.4f %16.4f %16.4f\n", 
			cam_scr[1][0], cam_scr[1][1], cam_scr[1][2], cam_scr[1][3]);
	printf ("%16.4f %16.4f %16.4f %16.4f\n", 
			cam_scr[2][0], cam_scr[2][1], cam_scr[2][2], cam_scr[2][3]);
	printf ("%16.4f %16.4f %16.4f %16.4f\n", 
			cam_scr[3][0], cam_scr[3][1], cam_scr[3][2], cam_scr[3][3]);
	*/

	// Camera -> Screen Matrix
	//
	fwrite (cam_scr, sizeof(float), 16, fd);

	// four lights (vector) packed into a matrix
	//
	float lightmatrix[4][4] = {
           // 0.8944f, -0.8944f,  0.0000f, 0.0000f,
           // 0.0000f,  0.0000f,  0.0000f, 0.0000f,
           // -0.4472f,  0.4472f,  0.0000f, 0.0000f,
           // 0.0000f,  0.0000f,  0.0000f, 1.0000f
           0.6155f, -0.8944f,  0.0000f, 0.0000f,
          -0.6155f,  0.0000f,  0.0000f, 0.0000f,
          -0.4924f,  0.4472f,  0.0000f, 0.0000f,
           0.0000f,  0.0000f,  0.0000f, 1.0000f
		};

	fwrite (lightmatrix, sizeof(float), 16, fd);
	
	// four light colors (vector) packed into a matrix
	//
	float lcolormatrix[4][4] = {
          // 0.0745f, 0.9607f, 0.0549f, 0.0000f,
          // 0.0000f, 0.0000f, 0.0000f, 0.0000f,
		  (245.00f/255.00f), (225.00f/255.00f), (80.00f/255.00f), 0.0f,
		  // ( 25.00f/255.00f), (130.00f/255.00f), (80.00f/255.00f), 0.0f,
		  ( 15.00f/255.00f), (70.00f/255.00f), (44.00f/255.00f), 0.0f,
          // 0.4588f, 0.1647f, 0.7490f, 0.0000f,
          0.0000f, 0.0000f, 0.0000f, 0.0000f,
          0.0000f, 0.0000f, 0.0000f, 0.0000f
	};
	
	fwrite (lcolormatrix, sizeof(float), 16, fd);
	
	// World -> Camera Matrix
	//
	float world_cam[4][4] = {
			1.0f, 0.0f,   0.0f, 0.0f,
			0.0f, 1.0f,   0.0f, 0.0f,
			0.0f, 0.0f,   1.0f, 0.0f,
			0.0f, 0.0f, 100.0f, 1.0f
		};

	fwrite (world_cam, sizeof(float), 16, fd);

	// initial (identy) local->world matrix
	//
	float local_world[4][4] = {
			1.0f, 0.0f, 0.0f, 0.0f,
			0.0f, 1.0f, 0.0f, 0.0f,
			0.0f, 0.0f, 1.0f, 0.0f,
			0.0f, 0.0f, 0.0f, 1.0f
		};

	fwrite (local_world, sizeof(float), 16, fd);
	
	float particle[53][4] = {
		-15.00, -30.00,  -5.00,   0.00,
		  0.00, -30.00,   0.00,   0.00,
		 15.00, -30.00,  -5.00,   0.00,
		 -7.50, -30.00,  -5.00,   0.00,
		  7.50, -30.00,  -5.00,   0.00,
		  0.00, -12.50,  10.00,  20.00,
		 -5.00, -10.00,  10.00,  20.00,
		  5.00, -10.00,  10.00,  20.00,
		 -5.00,  -2.50,  10.00,  20.00,
		  5.00,  -2.50,  10.00,  20.00,
		 -5.00,   5.00,  10.00,  20.00,
		  5.00,   5.00,  10.00,  20.00,
		  0.00,   5.00,  10.00,  20.00,
		 -5.00,   7.50,  10.00,  20.00,
		  5.00,   7.50,  10.00,  20.00,
		 -5.00,  15.00,  10.00,  20.00,
		  5.00,  15.00,  10.00,  20.00,
		 -5.00,  25.00,  10.00,  20.00,
		  5.00,  25.00,  10.00,  20.00,
		 -5.00,  13.00,  10.00,  20.00,
		  5.00,  13.00,  10.00,  20.00,
		-15.00, -21.00,   0.00,  20.00,
		-15.00, -17.00,   0.00,  20.00,
		-15.00, -13.00,   0.00,  20.00,
		-15.00,  -9.00,   0.00,  20.00,
		-15.00,  -5.00,   0.00,  20.00,
		 15.00, -21.00,   0.00,  20.00,
		 15.00, -17.00,   0.00,  20.00,
		 15.00, -13.00,   0.00,  20.00,
		 15.00,  -9.00,   0.00,  20.00,
		 15.00,  -5.00,   0.00,  20.00,
		  0.00, -21.00,   0.00,  20.00,
		  0.00, -17.00,   0.00,  20.00,
		  0.00, -13.00,   0.00,  20.00,
		 -7.50, -21.00,   0.00,  20.00,
		 -7.50, -17.00,   0.00,  20.00,
		 -7.50, -13.00,   0.00,  20.00,
		 -7.50,  -9.00,   0.00,  20.00,
		 -7.50,  -5.00,   0.00,  20.00,
		 -7.50,  -1.00,   0.00,  20.00,
		 -7.50,   3.00,   0.00,  20.00,
		 -7.50,   7.00,   0.00,  20.00,
		 -7.50,  11.00,   0.00,  20.00,
		  7.50, -21.00,   0.00,  20.00,
		  7.50, -17.00,   0.00,  20.00,
		  7.50, -13.00,   0.00,  20.00,
		  7.50,  -9.00,   0.00,  20.00,
		  7.50,  -5.00,   0.00,  20.00,
		  7.50,  -1.00,   0.00,  20.00,
		  7.50,   3.00,   0.00,  20.00,
		  7.50,   7.00,   0.00,  20.00,
		  7.50,  11.00,   0.00,  20.00,
		  0.00,  -5.00,  10.00,  20.00,
	};

	// orig pos
	fwrite (particle, sizeof(float), 212, fd);

	// prev pos
	fwrite (particle, sizeof(float), 212, fd);

	// particle acceleration
	/*
	float accel[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
	for (i=0; i<54; i++) {
		fwrite (accel, sizeof(float), 4, fd);
	}
	*/
	
	// List of Sticks
	//
	struct stick sticks[60] = {
		 5,  6,  5.59015f, 0,
		 5,  7,  5.59015f, 0,
		 6,  7, 10.00000f, 0,
		 6,  8,  7.50000f, 0,
		 7,  9,  7.50000f, 0,
		 8, 10,  7.50000f, 0,
		 6, 12, 12.53990f, 0,
		 7, 12, 12.53990f, 0,
		 9, 11,  7.50000f, 0,
		12, 13,  5.65685f, 0,
		12, 14,  5.65685f, 0,
		13, 14,  8.00000f, 0,
		13, 15, 15.00000f, 0,
		14, 16, 15.00000f, 0,
		15, 17, 15.00000f, 0,
		16, 18, 15.00000f, 0,
		 5, 12, 14.00000f, 0,
		10, 19,  3.00000f, 0,
		11, 20,  3.00000f, 0,
		 0, 21,  3.00000f, 0,
		21, 21,  3.00000f, 0,
		21, 22,  3.00000f, 0,
		22, 23,  3.00000f, 0,
		23, 24,  3.00000f, 0,
		24, 25,  3.00000f, 0,
		25, 10,  3.00000f, 0,
		 1, 31,  3.00000f, 0,
		31, 32,  3.00000f, 0,
		32, 33,  3.00000f, 0,
		33,  5,  3.00000f, 0,
		 2, 26,  3.00000f, 0,
		26, 27,  3.00000f, 0,
		26, 27,  3.00000f, 0,
		27, 28,  3.00000f, 0,
		28, 29,  3.00000f, 0,
		29, 30,  3.00000f, 0,
		30, 11,  3.00000f, 0,
		 3, 34,  3.00000f, 0,
		34, 35,  2.50000f, 0,
		35, 36,  3.00000f, 0,
		36, 37,  2.50000f, 0,
		37, 38,  3.00000f, 0,
		38, 39,  2.50000f, 0,
		39, 40,  3.00000f, 0,
		40, 41,  2.50000f, 0,
		41, 42,  3.00000f, 0,
		42, 13,  2.50000f, 0,
		 4, 43,  3.00000f, 0,
		43, 44,  2.50000f, 0,
		44, 45,  3.00000f, 0,
		45, 46,  2.50000f, 0,
		46, 47,  3.00000f, 0,
		47, 48,  2.50000f, 0,
		48, 49,  3.00000f, 0,
		49, 50,  2.50000f, 0,
		50, 51,  3.00000f, 0,
		51, 14,  2.50000f, 0,
		13, 52,  4.47213f, 0,
		14, 52,  4.47213f, 0,
		12, 52,  6.00000f, 0 
	};

	fwrite (sticks, sizeof(struct stick), 60, fd);

	// write out the limbs (where the meshes are drawn)
	struct limb limbs[12] = {
		 6,  8, 0, 0,
		 1.0, 0.75, 1.0, 1, 
		 7,  9, 0, 0,
		 1.0, 0.75, 1.0, 1, 
		 8, 10, 0, 0,
		 1.0, 0.75, 1.0, 1, 
		 9, 11, 0, 0,
		 1.0, 0.75, 1.0, 1, 
		13, 15, 0, 0,
		 1.5f, 1.5f, 1.5f, 1,
		14, 16, 0, 0,
		 1.5f, 1.5f, 1.5f, 1,
		15, 17, 0, 0, 
		 1.5f, 1.5f, 1.5f, 1,
		16, 18, 0, 0,
		 1.5f, 1.5f, 1.5f, 1,
		 5, 12, 7, 6, 
		 1.20f, 2.0f, 1.2f, 0,
		12, 52, 14, 13, 
		 1.0f, 1.0f, 1.0f, 0,
		 0,  0, 0, 0, 
		 1.0f, 1.0f, 1.0f, 1,
		 0,  0, 0, 0,
		 1.0f, 1.0f, 1.0f, 1
	};

	fwrite (limbs, sizeof(struct limb), 12, fd);

	// skip 5 qw that the program needs for itself
	uint32 empty=0;
	fwrite (&empty, sizeof(uint32), 20, fd);

	// write the 5 control point locations
	fwrite (particle, sizeof(float), 20, fd);

	SStripMesh limb;
	SStripMesh body;

	// now read in the raw mesh file created in Maya and pack it
	LoadStripMesh("limb.msh", &limb);

	// for each strip
	uint32 nqw = 0;
	uint32 nstrips = limb.mshHdr.numStrips;
	for (i=0; i<nstrips; i++) {
		uint32 offset = limb.pStrips[i].vertOffset;
		uint32 nverts = limb.pStrips[i].numVerts;
		LTVector4f *verts = &limb.pVerts[offset];	
		LTVector4f *norms = &limb.pNorms[offset];	
		
		// write strip control data
		// need to takeup entire quad word so dup data
		fwrite (&nstrips, sizeof (uint32), 1, fd);
		fwrite (&nverts, sizeof (uint32), 1, fd);
		fwrite (&nverts, sizeof (uint32), 1, fd);
		fwrite (&nverts, sizeof (uint32), 1, fd);
		nqw++;

		// printf ("\nSTRIP #%d\n", i);
		for (j=0; j<nverts; j++) {
			// printf ("pos:  [%15.12f\t%15.12f\t%15.12f\t%15.12f]\n",
			// 		verts[j][0], verts[j][1], verts[j][2], verts[j][3]);
			// printf ("norm: [%15.12f\t%15.12f\t%15.12f\t%15.12f]\n",
			// 		norms[j][0], norms[j][1], norms[j][2], norms[j][3]);
			fwrite (verts[j], sizeof (LTVector4f), 1, fd);
			fwrite (norms[j], sizeof (LTVector4f), 1, fd);
			nqw += 2;
		}
	}
	printf ("Wrote %d qw for limb mesh data \n", nqw);

	// now read in the raw mesh file created in Maya and pack it
	LoadStripMesh("body.msh", &body);

	// for each strip
	nstrips = body.mshHdr.numStrips;
	for (i=0; i<nstrips; i++) {
		uint32 offset = body.pStrips[i].vertOffset;
		uint32 nverts = body.pStrips[i].numVerts;
		LTVector4f *verts = &body.pVerts[offset];	
		LTVector4f *norms = &body.pNorms[offset];	
		
		// write strip control data
		// need to takeup entire quad word so dup data
		fwrite (&nstrips, sizeof (uint32), 1, fd);
		fwrite (&nverts, sizeof (uint32), 1, fd);
		fwrite (&nverts, sizeof (uint32), 1, fd);
		fwrite (&nverts, sizeof (uint32), 1, fd);
		nqw++;

		for (j=0; j<nverts; j++) {
			// printf ("norm: [%15.12f\t%15.12f\t%15.12f\t%15.12f]\n",
			//		norms[j][0], norms[j][1], norms[j][2], norms[j][3]);
			fwrite (verts[j], sizeof (LTVector4f), 1, fd);
			fwrite (norms[j], sizeof (LTVector4f), 1, fd);
			nqw += 2;
		}
	}

	printf ("Wrote %d qw total mesh data \n", nqw);
	
	// minimum and maximum vector
	minvbig[0] = -45.0f;
	minvbig[1] = -60.0f;
	minvbig[2] = -75.0f;
	minvbig[3] = 0.0f;
	maxvbig[0] = 45.0f;
	maxvbig[1] = 32.0f;
	maxvbig[2] = 100.0f;
	maxvbig[3] = 0.0;
	
	// write out the line list for drawing the box she is in
	LTVector4f tmp;
	tmp[3] = 1.0f;

	// line strip 1
	tmp[0] = 1.0;
	tmp[1] = 0.0;
	tmp[2] = 0.0;
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	//tmp[0] = minvbig[0];
	//tmp[1] = maxvbig[1];
	//tmp[2] = minvbig[2];
	//fwrite (tmp, sizeof (LTVector4f), 1, fd);

	// line strip 2
	tmp[0] = -1.0;
	tmp[1] = 0.0;
	tmp[2] = 0.0;
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	//tmp[0] = maxvbig[0];
	//tmp[1] = maxvbig[1];
	//tmp[2] = minvbig[2];
	//fwrite (tmp, sizeof (LTVector4f), 1, fd);

	// line strip 3
	tmp[0] = 0.0;
	tmp[1] = 0.0;
	tmp[2] = -1.0;
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	//tmp[0] = minvbig[0];
	//tmp[1] = maxvbig[1];
	//tmp[2] = maxvbig[2];
	//fwrite (tmp, sizeof (LTVector4f), 1, fd);
	
	// line strip 4
	tmp[0] = 0.0;
	tmp[1] = 0.0;
	tmp[2] = 1.0;
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = maxvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	//tmp[0] = minvbig[0];
	//tmp[1] = maxvbig[1];
	//tmp[2] = maxvbig[2];
	//fwrite (tmp, sizeof (LTVector4f), 1, fd);
	
	// line strip 5
	tmp[0] = 0.0;
	tmp[1] = 0.0;
	tmp[2] = 1.0;
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = minvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = minvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	tmp[0] = maxvbig[0];
	tmp[1] = minvbig[1];
	tmp[2] = maxvbig[2];
	fwrite (tmp, sizeof (LTVector4f), 1, fd);

	//tmp[0] = minvbig[0];
	//tmp[1] = maxvbig[1];
	//tmp[2] = maxvbig[2];
	//fwrite (tmp, sizeof (LTVector4f), 1, fd);

	fclose (fd);
}
